==> cms-db_v0.7.11.tar.gz: admin/locales/en/locale_variables.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['variables'] = array();

$locale['variables']['title'] = 'Variables';
$locale['variables']['desc'] = 'You can use all of the variables in the <a href="%s">template</a>, all except PAGECONTENT can be used in the <a href="%s">pages</a>, too. No variables are replaced in guestbook entries or blog articles.';

$locale['variables']['desc_p-allowed'] = 'can be placed in a paragraph';
$locale['variables']['desc_p-alone'] = 'can be placed in a paragraph, but has to be its only content';
$locale['variables']['desc_p-disallowed'] = 'can\'t be placed in a paragraph';
$locale['variables']['desc_p-needed'] = 'must be placed in a paragraph and has to be its only content';

$locale['variables']['desc_topmenu'] = 'Creates a menu of the top level pages';
$locale['variables']['desc_completesubmenu'] = 'Creates a menu that displays all sub-pages of the current top level page';
$locale['variables']['desc_foldingsubmenu'] = 'Creates a menu which display sub-pages of the current top level page depending on the current sub page';
$locale['variables']['desc_completemenu'] = 'Creates a complete menu for the website';
$locale['variables']['desc_foldingmenu'] = 'Creates a menu for the whole website which displays sub pages depending on the current page';
$locale['variables']['desc_pagesearch'] = 'Displayes a search box';
$locale['variables']['desc_pagetitle'] = 'Displays the name of the current page';
$locale['variables']['desc_fulltitle'] = 'Name of the current page with page structure';
$locale['variables']['desc_breadcrumbs'] = 'Same as %%FULLTITLE%%, but with links to the pages';
$locale['variables']['desc_pagecontent'] = 'Displays the content of the current page';
$locale['variables']['desc_lastedit'] = 'Displays the time of the last change on the current page';
$locale['variables']['desc_pagecount'] = 'Counts the number of page impressions and displays it';
$locale['variables']['desc_counter'] = 'Displays the number of visitors';
$locale['variables']['desc_sitemap'] = 'Creates a sitemap, a wrapping paragraph is automatically removed';
$locale['variables']['desc_mailform'] = 'Displays a contact form which sends mails to the specified ADDRESS, a wrapping paragraph is automatically removed';
$locale['variables']['desc_guestbook'] = 'Displays a guestbook with form, the charset has to be UTF-8 and a wrapping paragraph is automatically removed';
$locale['variables']['desc_blog'] = 'Displays the blog, the charset has to be UTF-8 and a wrapping paragraph is automatically removed';
$locale['variables']['desc_latestblogarticles'] = 'Displays a list of the latest blog entries, PAGE is the short url of the page which displays the blog';
$locale['variables']['desc_tagcloud'] = 'Displays a tag cloud for the blog, PAGE is the short url of the page which displays the blog';
$locale['variables']['desc_sectionlist'] = 'Displays a list of links to direct sub-pages of the current page, , a wrapping paragraph is automatically removed';
$locale['variables']['desc_loginform'] = 'Displays a login form, a wrapping paragraph is automatically removed';
$locale['variables']['desc_include'] = 'Displays the Include NAME, a wrapping paragraph is automatically removed';
$locale['variables']['desc_redirect'] = 'Redirect to the specified URL, the page contents aren\'t displayed';
$locale['variables']['desc_forcelanguage'] = 'Changes the language used for generated content to the specified LANGCODE';
$locale['variables']['desc_urlsettings'] = 'Returns the URL preferences';
$locale['variables']['desc_condition'] = 'The content between the two variables is only displayed when the PHP condition COND is true, %%CONDITION-(COND)%% and %%ENDCONDITION%% must be in separate paragraphs';

?>

==> cms-db_v0.8.1.tar.gz: admin/locales/en/locale_variables.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['variables'] = array();

$locale['variables']['title'] = 'Variables';
$locale['variables']['desc'] = 'You can use all of the variables in the <a href="%s">template</a>, all except PAGECONTENT can be used in the <a href="%s">pages</a>, too. No variables are replaced in guestbook entries or blog articles.';

$locale['variables']['title_variables-menu'] = 'Menus';
$locale['variables']['title_variables-contentstructure'] = 'Content and Structure';
$locale['variables']['title_variables-dynamic'] = 'Dynamic Content';
$locale['variables']['title_variables-blog'] = 'Blog';
$locale['variables']['title_variables-misc'] = 'Miscellaneous';

$locale['variables']['desc_p-allowed'] = 'can be placed in a paragraph';
$locale['variables']['desc_p-alone'] = 'can be placed in a paragraph, but has to be its only content';
$locale['variables']['desc_p-disallowed'] = 'can\'t be placed in a paragraph';
$locale['variables']['desc_p-needed'] = 'must be placed in a paragraph and has to be its only content';

$locale['variables']['desc_topmenu'] = 'Creates a menu of the top level pages';
$locale['variables']['desc_completesubmenu'] = 'Creates a menu that displays all sub-pages of the current top level page';
$locale['variables']['desc_foldingsubmenu'] = 'Creates a menu which display sub-pages of the current top level page depending on the current sub page';
$locale['variables']['desc_completemenu'] = 'Creates a complete menu for the website';
$locale['variables']['desc_foldingmenu'] = 'Creates a menu for the whole website which displays sub pages depending on the current page';
$locale['variables']['desc_pagesearch'] = 'Displayes a search box';
$locale['variables']['desc_pagetitle'] = 'Displays the name of the current page';
$locale['variables']['desc_fulltitle'] = 'Name of the current page with page structure';
$locale['variables']['desc_breadcrumbs'] = 'Same as %%FULLTITLE%%, but with links to the pages';
$locale['variables']['desc_pagecontent'] = 'Displays the content of the current page';
$locale['variables']['desc_lastedit'] = 'Displays the time of the last change on the current page';
$locale['variables']['desc_pagecount'] = 'Counts the number of page impressions and displays it';
$locale['variables']['desc_counter'] = 'Displays the number of visitors';
$locale['variables']['desc_sitemap'] = 'Creates a sitemap, a wrapping paragraph is automatically removed';
$locale['variables']['desc_mailform'] = 'Displays a contact form which sends mails to the specified ADDRESS, a wrapping paragraph is automatically removed';
$locale['variables']['desc_guestbook'] = 'Displays a guestbook with form, the charset has to be UTF-8 and a wrapping paragraph is automatically removed';
$locale['variables']['desc_blog'] = 'Displays the blog, the charset has to be UTF-8 and a wrapping paragraph is automatically removed';
$locale['variables']['desc_latestblogarticles'] = 'Displays a list of the latest blog entries, PAGE is the short url of the page which displays the blog';
$locale['variables']['desc_tagcloud'] = 'Displays a tag cloud for the blog, PAGE is the short url of the page which displays the blog';
$locale['variables']['desc_completeblogfeed'] = 'Displays a link to the complete blog feed, PAGE is the short url of the page which displays the blog';
$locale['variables']['desc_allblogfeeds'] = 'Displays a list of all available blog feeds (by tags), PAGE is the short url of the page which displays the blog. a wrapping paragraph is automatically removed';
$locale['variables']['desc_contextblogfeeds'] = 'Displays a context sensitive list of blog feeds (only in the blog), PAGE is the short url of the page which displays the blog, a wrapping paragraph is automatically removed';
$locale['variables']['desc_sectionlist'] = 'Displays a list of links to direct sub-pages of the current page, a wrapping paragraph is automatically removed';
$locale['variables']['desc_loginform'] = 'Displays a login form, a wrapping paragraph is automatically removed';
$locale['variables']['desc_include'] = 'Displays the Include NAME, a wrapping paragraph is automatically removed, late includes are replaced at the latest possible time';
$locale['variables']['desc_redirect'] = 'Redirect to the specified URL, the page contents aren\'t displayed';
$locale['variables']['desc_forcelanguage'] = 'Changes the language used for generated content to the specified LANGCODE';
$locale['variables']['desc_urlsettings'] = 'Returns the URL preferences';
$locale['variables']['desc_completeurl'] = 'Displays the complete url of the current page (with domain)';
$locale['variables']['desc_condition'] = 'The content between the two variables is only displayed when the PHP condition COND is true, %%CONDITION-(COND)%% and %%ENDCONDITION%% must be in separate paragraphs';

?>
